AstronomicalSimulation

Struct AstronomicalSimulation 

pub struct AstronomicalSimulation {
    pub(crate) location: SimulatedLocation,
}
Hijri Rules based on an astronomical simulation for a particular location.

These simulations are unofficial and are known to not necessarily match sightings on the ground. Unless you know otherwise for sure, instead of this variant, use UmmAlQura, which uses the results of KACST’s Mecca-based calculations.

As floating point arithmetic degenerates for far-away dates, this falls back to the tabular calendar at some point.

The precise behavior of this calendar may change in the future if:

  • We decide to tweak the precise astronomical simulation used
  • We decide to expand or reduce the range where we are using the astronomical simulation.

This corresponds to the "islamic-rgsa" CLDR calendar if constructed with Hijri::new_simulated_mecca().

Fields

location: SimulatedLocation