UmmAlQura

Struct UmmAlQura 

#[non_exhaustive]
pub struct UmmAlQura;
Hijri Rules for the Umm al-Qura calendar.

From the start of 1300 AH (1882-11-12 ISO) to the end of 1600 AH (2174-11-25 ISO), this Rules implementation uses Umm al-Qura month lengths obtained from KACST. Outside this range, this implementation falls back to TabularAlgorithm with TabularAlgorithmLeapYears::TypeII and TabularAlgorithmEpoch::Friday.

The precise behavior of this calendar may change in the future if:

  • New ground truth is established by published government sources
  • We decide to use a different algorithm outside the KACST range
  • We decide to expand or reduce the range where we are correctly handling past dates.

This corresponds to the "islamic-umalqura" CLDR calendar.