pub struct AstronomicalSimulation {
pub(crate) location: SimulatedLocation,
}Expand description
Hijri Rules based on an astronomical simulation for a particular location.
These simulations are unofficial and are known to not necessarily match sightings
on the ground. Unless you know otherwise for sure, instead of this variant, use
UmmAlQura, which uses the results of KACST’s Mecca-based calculations.
As floating point arithmetic degenerates for far-away dates, this falls back to the tabular calendar at some point.
The precise behavior of this calendar may change in the future if:
- We decide to tweak the precise astronomical simulation used
- We decide to expand or reduce the range where we are using the astronomical simulation.
This corresponds to the "islamic-rgsa" CLDR calendar
if constructed with Hijri::new_simulated_mecca().
Fields
location: SimulatedLocationTrait Implementations
Sourceimpl Clone for AstronomicalSimulation
impl Clone for AstronomicalSimulation
Sourcefn clone(&self) -> AstronomicalSimulation
fn clone(&self) -> AstronomicalSimulation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AstronomicalSimulation
impl Debug for AstronomicalSimulation
Sourceimpl Rules for AstronomicalSimulation
impl Rules for AstronomicalSimulation
Sourcefn debug_name(&self) -> &'static str
fn debug_name(&self) -> &'static str
The debug name for these rules.
Sourcefn year_data(&self, extended_year: i32) -> HijriYearData
fn year_data(&self, extended_year: i32) -> HijriYearData
Returns data about the given year.
Sourcefn ecma_reference_year(
&self,
_month_code: (u8, bool),
_day: u8,
) -> Result<i32, EcmaReferenceYearError>
fn ecma_reference_year( &self, _month_code: (u8, bool), _day: u8, ) -> Result<i32, EcmaReferenceYearError>
Returns an ECMA reference year that contains the given month-day combination. Read more
Sourcefn calendar_algorithm(&self) -> Option<CalendarAlgorithm>
fn calendar_algorithm(&self) -> Option<CalendarAlgorithm>
The BCP-47
CalendarAlgorithm for the Hijri calendar using these rules, if defined.impl Copy for AstronomicalSimulation